"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.default = void 0;

var _reactNative = require("react-native");

function _defineProperty(obj, key, value) { if (key in obj) { Object.defineProperty(obj, key, { value: value, enumerable: true, configurable: true, writable: true }); } else { obj[key] = value; } return obj; }

const {
  Audio
} = _reactNative.NativeModules;
const AudioEmitter = new _reactNative.NativeEventEmitter(Audio);

class AudioSdk {
  constructor(callback) {
    _defineProperty(this, "mode", void 0);

    _defineProperty(this, "audioCallbacks", void 0);

    _defineProperty(this, "state", void 0);

    _defineProperty(this, "initializeSdk", () => {
      AudioEmitter.addListener(Audio.DEVICE_CHANGE_EVENT, this.onDevicesUpdate, this);
    });

    this.audioCallbacks = callback;
    this.state = {
      devices: []
    };
    this.initializeSdk();
  }

  updateDevices(devices) {
    this.state.devices = devices;

    if (this.audioCallbacks) {
      this.audioCallbacks.onAudioDevicesUpdated(this.state.devices);
    } else {
      console.log('AudioCallbacks is undefined!');
    }
  }
  /**
   * Handles audio device changes. The list will be stored on the redux store.
   *
   * @param {Object} devices - The current list of devices.
   * @private
   * @returns {void}
   */


  onDevicesUpdate(devices) {
    this.updateDevices(devices);
  }
  /**
   * Updates the audio mode based on the current (redux) state.
   *
   * @public
   * @returns {void}.
   */


  updateAudioMode(inCall, isVideo, isSilent) {
    this.mode = inCall ? isSilent ? Audio.SILENT : isVideo ? Audio.VIDEO_CALL : Audio.AUDIO_CALL : Audio.DEFAULT;
    Audio.setMode(this.mode).catch(err => console.log(`Failed to set audio mode ${String(this.mode)}: ${err}`));
  }

  updateDeviceList() {
    Audio.updateDeviceList && Audio.updateDeviceList();
  }

  updateAudioDevice(type) {
    try {
      Audio.setAudioDevice(type);
    } catch (error) {
      console.log(`Failed to set audio device ${String(type)}: ${error}`);
    } // switch(type) {
    //     case 'Speaker':
    //         AudioLibrary.setAudioDevice("SPEAKER");
    //         break;
    //     case 'Headphone':
    //         AudioLibrary.setAudioDevice("HEADPHONES");
    //         break;
    //     default:
    //         console.log('default updateAudioDevice type:', type);
    // }

  }

}

exports.default = AudioSdk;
//# sourceMappingURL=AudioSdk.js.map